Activates the bs_page_item() carrying selected as its value inside the
bs_pagination() registered under id, and reports the change back as
input$id.
Usage
update_bs_pagination(
id,
selected = NULL,
session = shiny::getDefaultReactiveDomain()
)Arguments
- id
Pager id, as passed to
bs_pagination()orbs_pagination_numbered().- selected
valueof the item to activate. For a numbered pager this is the page number as a string.- session
The Shiny session.
Examples
if (interactive()) update_bs_pagination("pager", selected = "3")